// O(M * N * 2^N)
// Not deeply checked/tested yet.

#include <bitset>
#include <cassert>
#include <cstdint>
#include <iomanip>
#include <iostream>
#include <limits>
#include <map>
#include <unordered_map>
#include <vector>
// #include <format>

using namespace std;

using LineCounts = vector<unordered_map<uint64_t, int>>;
using Memo = vector<unordered_map<uint64_t, double>>;

LineCounts precompute(const vector<uint64_t> &lines, int N) {
  // Vector indexed by a bitset with the k bits at the positions
  // corresponding to the stations that have a constraint. There are 2^N
  // such indexes.
  // Map indexed by a bitset with 0 or 1 at the i-th position (for all
  // i's where the vector index bitset has a 1), whether the line must
  // through the i-th station. We only fill values for bitsets with at
  // least one line. There are at most M such values.
  // Total size is therefore at most M * 2^N.
  LineCounts line_counts(1ULL << N);
  assert(!lines.empty());
  assert(N <= 64);
  for (const uint64_t &line : lines) {
    for (uint64_t mask = 0; mask < (1ULL << N); ++mask) {
      ++line_counts[mask][line & mask];
    }
  }
  return line_counts;
}

int get_line_count(uint64_t constraint_locations, uint64_t constraints,
                   const LineCounts &line_counts) {
  const auto &with_locations = line_counts[constraint_locations];
  auto it = with_locations.find(constraints);
  return it == with_locations.end() ? 0 : it->second;
}

// Computes the minimum number of questions that need to be asked given:
// - 'contraint_locations': bitset where the i-th bit says whether we've
//   already asked a question about station i.
// - 'constraints': bitset where the i-th bit says whether the line to
//   guess passes through station i (assuming we asked about station
//   i). The bits at stations we did not ask about are 0s.
//
// This is the minimum over all i's (where the i-th bit of
// constraint_locations is 0) of:
//
// 1 + P(player A responds false for station i) * dp_v1(updated state
// where we asked for station i and the line to guess does not pass
// through it) + P(player A responds true for station i) *
// dp_v1(updated state where we asked for station i and the line to
// guess does pass through it).
//
// where the probabilities are computed as:
//
// P(player A responds false for station i) = card({line | line does not pass
// through station i and matches 'contraints_locations' and 'constraints'}) /
// card({line | line matches 'contraints_locations' and 'constraints'})
//
// // P(player A responds true for station i) = card({line | line does pass
// through station i and matches 'contraints_locations' and 'constraints'}) /
// card({line | line matches 'contraints_locations' and 'constraints'})
double dp_v1(uint64_t constraint_locations, uint64_t constraints, int N,
             const LineCounts &line_counts, Memo &memo) {
  const int cur_line_count =
      get_line_count(constraint_locations, constraints, line_counts);
  if (cur_line_count <= 1)
    return 0; // Can decide without any additional question.
  auto &memo_with_locations = memo[constraint_locations];
  auto it = memo_with_locations.find(constraints);
  if (it != memo_with_locations.end())
    return it->second;
  double res = numeric_limits<double>::max();
  for (int i = 0; i < N; ++i) {
    if ((constraint_locations >> i) & 1) {
      // There is already a constraint for station i.
      continue;
    }
    const uint64_t new_constraint_locations =
        constraint_locations | (1ULL << i);
    // Ask question about station i.
    res = min(
        res,
        1 +
            // Line passes through station i.
            dp_v1(new_constraint_locations, constraints | (1ULL << i), N,
                  line_counts, memo) *
                get_line_count(new_constraint_locations,
                               constraints | (1ULL << i), line_counts) /
                cur_line_count +
            // Line does not pass through station i.
            dp_v1(new_constraint_locations, constraints, N, line_counts, memo) *
                get_line_count(new_constraint_locations, constraints,
                               line_counts) /
                cur_line_count);
  }
  //  cout << bitset<10>(constraint_locations) << " " <<
  //  bitset<10>(constraint_locations) << " " << res << endl;
  return (memo_with_locations[constraints] = res);
}

int main() {
  while (cin.peek() == '#' || cin.peek() == '/') {
    string s;
    getline(cin, s);
  }
  int N;
  cin >> N;
  assert(N <= 64); // For bit masks to fit in an uint64_t.
  int M;
  cin >> M;
  vector<uint64_t> lines;
  for (int i = 0; i < M; ++i) {
    uint64_t line = 0;
    int num_stations;
    cin >> num_stations;
    for (int j = 0; j < num_stations; ++j) {
      int station;
      cin >> station;
      assert(station >= 0);
      assert(station < N);
      uint64_t station_mask = 1ULL << station;
      // Duplicate station.
      assert((line & station_mask) == 0);
      line |= station_mask;
    }
    lines.push_back(line);
  }
  double t = time(nullptr);
  LineCounts line_counts = precompute(lines, N);
  //  cout << "precompute time: " << time(nullptr) - t << endl;
  t = time(nullptr);
  Memo memo;
  memo.resize(1ULL << N);
  double res = dp_v1(0, 0, N, line_counts, memo);
  // cout << "DP time: " << time(nullptr) - t << endl;
  if (res > 2 * N) {
    cout << "not possible" << endl;
  } else {
    cout << std::setprecision(15) << res << endl;
  }
}
